--[[
  MTarget - Config Functions ($Id$)
  Written by gameldar
  http://www.wowace.com/projects/mtarget

  Thanks to:
    Ace3: Great lib framework
  ]]--

local L = LibStub("AceLocale-3.0"):GetLocale("MTarget", true);

function MTarget:Config_OnInitialize()
local options = {
        name = "MTarget",
        handler = MTarget,
        hidden = false,
        type = 'group',
        args = {
	        autowrite = {
	            type = 'toggle',
	            name = L['Auto Write Macros'],
	            desc = L['Rewrite the macros when a variable is changed.'],
	            set = 'SetAutoWrite',
	            get = 'GetAutoWrite',
	        },
	        showtooltips = {
	            type = 'toggle',
	            name = L['Show Tooltips'],
	            desc = L['Show tooltips on menu items.'],
	            set = 'SetShowTooltips',
	            get = 'GetShowTooltips',
	        },
	        broadcast = {
	            type = 'toggle',
	            name = L['Broadcast variables'],
	            desc = L['Broadcast variables to party or raid'],
	            set = 'SetBroadcast',
	            get = 'GetBroadcast',
	        },
	        autoaccept = {
	            type = 'toggle',
	            name = L['Auto accept Broadcasts'],
	            desc = L['Always accept broadcast from party/raid members'],
	            set = 'SetAutoAccept',
	            get = 'GetAutoAccept',
	        },
	        raidtargets = {
	            type = 'toggle',
	            name = L['Assign Raid Icons'],
	            desc = L['Automatically assign raid icons to varibles when you set them ("$star","$circle","$diamond","$triangle","$moon","$square","$cross","$skull")'],
	            set = 'SetRaidTargets',
	            get = 'GetRaidTargets',
	        },
	        debug = {
	            type = 'toggle',
	            name = L['Debug'],
	            desc = L['Enable debug output'],
	            set = 'SetDebug',
	            get = 'GetDebug',
	        },
          hide = {
              type = 'toggle',
              name = L['Hide Minimap Icon'],
              desc = L['Hide the minimap icon'],
              set = 'SetMinimap',
              get = 'GetMinimap',
          },
	        tankassign = {
	            type = 'toggle',
	            name = L['Use Tank Assignments'],
	            desc = L['Automatically assign $maintank and $mainassist variables when they are set in the group/raid.'],
	            set = 'SetTankAssign',
	            get = 'GetTankAssign',
	        },
	        tankroles = {
	            type = 'toggle',
	            name = L['Use Tank Roles'],
	            desc = L['Automatically assign $maintank and $mainassist variables to players with the tank role when in a group/raid. Note: This requires Use Tank Assignments to be on.'],
	            set = 'SetTankRoles',
	            get = 'GetTankRoles',
	        },
	        autotalent = {
	            type = 'toggle',
	            name = L['Assign Talent Tier'],
	            desc = L['Automatically assign $tier# variables to the name of the talents selected at each tier(1-6).'],
	            set = 'SetAutoTalent',
	            get = 'GetAutoTalent',
	        },
          autocreate = {
              type = 'toggle',
              name = L['Auto create templates'],
              desc = L['Automatically create templates from macros that contain wildcards ($x)'],
              set = 'SetAutoCreate',
              get = 'GetAutoCreate',
          },
          autodelete = {
              type = 'toggle',
              name = L['Delete templates with macro'],
              desc = L['Automatically delete the template when the macro is deleted.'],
              set = 'SetAutoDelete',
              get = 'GetAutoDelete',
          },
        },
    };
    
  options.args.profile = LibStub("AceDBOptions-3.0"):GetOptionsTable(MTarget.db);
  
  config = LibStub("AceConfig-3.0");
  MTarget.configdialog = LibStub("AceConfigDialog-3.0");
  config:RegisterOptionsTable("MTarget", options, {"mtargconf"});
  MTarget.configdialog:SetDefaultSize("MTarget", 1000, 600);

  config:RegisterOptionsTable( "MTarget", options )
  MTarget.configdialog:AddToBlizOptions( "MTarget", "MTarget")
  MTarget.db.RegisterCallback(MTarget, "OnProfileChanged", "Config_Refresh");
  MTarget.db.RegisterCallback(MTarget, "OnProfileCopied", "Config_Refresh");
  MTarget.db.RegisterCallback(MTarget, "OnProfileReset", "Config_Refresh");
end

function MTarget:Config_Refresh()
  MTarget:Macro_WriteAll(true);
end

function MTarget:Config_OnEnable()
  if (not MTarget.db.char.templates) then
    MTarget.db.char.templates = {};
  end

  if (not MTarget.db.profile) then
    MTarget.db.profile = {}
    MTarget.db.profile.autowrite = true;
    MTarget.db.profile.debug = false;
    MTarget.db.profile.hide = false;
    MTarget.db.profile.tankassign = false;
    MTarget.db.profile.tankroles = false;
    MTarget.db.profile.autotalent = false;
  end

  if (MTarget.db.char.variables) then
    MTarget.db.profile.variables = MTarget.db.char.variables;
    MTarget.db.char.variables = nil;
  end

  if (not MTarget.db.profile.variables) then
    MTarget.db.profile.variables = {};
  end
  
  if (MTarget.db.char.vnames) then
    MTarget.db.profile.vnames = MTarget.db.char.vnames;
    MTarget.db.char.vnames = nil;
  end

  if (not MTarget.db.profile.vnames) then
    MTarget.db.profile.vnames = {};
  end
end

function MTarget:SetAutoWrite(info, input)
  MTarget.db.profile.autowrite = input
end

function MTarget:GetAutoWrite(info)
  return MTarget.db.profile.autowrite
end

function MTarget:SetShowTooltips(info, input)
  MTarget.db.profile.showtooltips = input
end
function MTarget:GetShowTooltips(info)
  return MTarget.db.profile.showtooltips
end

function MTarget:SetBroadcast(info, input)
  MTarget.db.profile.broadcast = input
end
function MTarget:GetBroadcast(info)
  return MTarget.db.profile.broadcast
end
function MTarget:SetAutoAccept(info, input)
  MTarget.db.profile.autoaccept = input
end
function MTarget:GetAutoAccept(info)
  return MTarget.db.profile.autoaccept
end
function MTarget:SetRaidTargets(info, input)
  MTarget.db.profile.raidtargets = input
end
function MTarget:GetRaidTargets(info)
  return MTarget.db.profile.raidtargets
end
function MTarget:SetDebug(info, input)
  MTarget.db.profile.debug = input
end
function MTarget:GetDebug(info)
  return MTarget.db.profile.debug
end
function MTarget:SetMinimap(info, input)
  MTarget.db.profile.hide = input
  if input then
    MTarget.icon:Hide("MTargetDB")
  else
    MTarget.icon:Show("MTargetDB")
  end
end
function MTarget:GetMinimap(info)
  return MTarget.db.profile.hide
end

function MTarget:SetTankAssign(info, input)
  MTarget.db.profile.tankassign = input
end

function MTarget:GetTankAssign(info)
  return MTarget.db.profile.tankassign
end

function MTarget:SetTankRoles(info, input)
  MTarget.db.profile.tankroles = input
end

function MTarget:GetTankRoles(info)
  return MTarget.db.profile.tankroles
end

function MTarget:SetAutoTalent(info, input)
  MTarget.db.profile.autotalent = input
end

function MTarget:GetAutoTalent(info)
  return MTarget.db.profile.autotalent
end

function MTarget:SetAutoCreate(info, input)
  MTarget.db.profile.autocreate = input
end

function MTarget:GetAutoCreate(info)
  return MTarget.db.profile.autocreate
end

function MTarget:SetAutoDelete(info, input)
  MTarget.db.profile.autodelete = input
end

function MTarget:GetAutoDelete(info)
  return MTarget.db.profile.autodelete
end

function MTarget:Console_Cmd_config(input)
  InterfaceOptionsFrame_OpenToCategory("MTarget");
end

